[COMMITTED,4/6] sframe: correct some typos

Message ID 20230419221125.502883-5-indu.bhagat@oracle.com
State Accepted
Headers
Series Minor sframe related patches |

Checks

Context Check Description
snail/binutils-gdb-check success Github commit url

Commit Message

Indu Bhagat April 19, 2023, 10:11 p.m. UTC
  include/
	* sframe.h: Correct a typo.

libsframe/
	* sframe.c: Likewise.
---
 include/sframe.h   | 4 ++--
 libsframe/sframe.c | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)
  

Patch

diff --git a/libsframe/sframe.c b/libsframe/sframe.c
index 907214a8a89..b2c8eacae14 100644
--- a/libsframe/sframe.c
+++ b/libsframe/sframe.c
@@ -970,7 +970,7 @@  sframe_get_funcdesc_with_addr (sframe_decoder_ctx *ctx,
       if (fdp[mid].sfde_func_start_address < addr)
 	{
 	  if (mid == (cnt - 1)) 	/* Check if it's the last one.  */
-	    return fdp + (cnt - 1) ;
+	    return fdp + (cnt - 1);
 	  else if (fdp[mid+1].sfde_func_start_address > addr)
 	    return fdp + mid;
 	  low = mid + 1;
diff --git a/include/sframe.h b/include/sframe.h
index 58907d73413..c3dbb3a4097 100644
--- a/include/sframe.h
+++ b/include/sframe.h
@@ -146,9 +146,9 @@  typedef struct sframe_header
      not fixed, it is set to SFRAME_CFA_FIXED_RA_INVALID, and individual
      FREs provide the applicable stack frame offset, if any.  */
   int8_t sfh_cfa_fixed_ra_offset;
   /* Number of bytes making up the auxilliary header, if any.
      Some ABI/arch, in the future, may use this space for extending the
-     information in SFrame header.  Auxilliary header is contained in
+     information in SFrame header.  Auxiliary header is contained in
      bytes sequentially following the sframe_header.  */
   uint8_t sfh_auxhdr_len;
   /* Number of SFrame FDEs in this SFrame section.  */
@@ -146,9 +146,9 @@  typedef struct sframe_header
      FREs provide the applicable stack frame offset, if any.  */
   int8_t sfh_cfa_fixed_ra_offset;
-  /* Number of bytes making up the auxilliary header, if any.
+  /* Number of bytes making up the auxiliary header, if any.
      Some ABI/arch, in the future, may use this space for extending the